(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     72041,       2062]*)
(*NotebookOutlinePosition[     72671,       2084]*)
(*  CellTagsIndexPosition[     72627,       2080]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    StyleBox[\( (*\(\(--\(--START\)\)\ UP\ of\ \(shear--\)\)\(-\)\ *) \),
      FontColor->RGBColor[1, 0, 0]]], "Input"],

Cell[BoxData[
    \(\(Off[General::spell1];\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ LOAD\ DATA\ FILES\ *) \),
        FontColor->RGBColor[0, 0, 1]], 
      "\[IndentingNewLine]", \(\(\(\(SetDirectory["\<~/Desktop/dropdef\>"]\) \
\);\) (*Note : \ 
          change\ the\ path\ to\ point\ to\ the\ directory\ where\ you\ have\ \
put\ the\ \(files!\)*) \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]\[IndentingNewLine]
      \(\(<< "\<evol_eqs.m\>"\)\(\ \)\(;\)\( (*eqF20f, eqF22f, eqF22nf, 
        eqF40f, eqF42f, eqF42nf, eqF44f, eqF44nf, eqG20f, eqG22f, eqG22nf, 
        eqG40f, eqG42f, eqG42nf, eqG44f, eqG44nf*) \)\)\)}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"\[IndentingNewLine]", 
      StyleBox[\( (*\ definitions\ *) \),
        FontColor->RGBColor[0, 0, 1]], 
      StyleBox["\[IndentingNewLine]",
        FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      StyleBox[\( (*position\ of\ the\ interface\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{\(r[theta_, phi_] := 
            1 + \((\(\(-1\)/4\)/
                    Pi*\((f20[t]^2 + 2*\((f22[t]^2 + f22n[t]^2)\))\))\) + 
              f20[t]*1/8*Sqrt[5/Pi]*\((1 + 3\ Cos[2\ theta])\)\  + 
              f22[t]*\((1\/2\ \@\(15\/\(2\ \[Pi]\)\)\ Cos[
                      2\ phi]\ Sin[theta]\^2)\) + 
              f22n[t]*\((\(-\@\(15\/\(2\ \[Pi]\)\)\)\ Cos[phi]\ Sin[
                      phi]\ Sin[theta]\^2)\) + 
              f40[t]*\((\(3\ \((3 - 30\ Cos[theta]\^2 + 35\ \
Cos[theta]\^4)\)\)\/\(16\ \@\[Pi]\))\) + 
              f42[t]*\((3\/8\ \@\(5\/\(2\ \[Pi]\)\)\ Cos[
                      2\ phi]\ \((5 + 7\ Cos[2\ theta])\)\ Sin[theta]\^2)\) + 
              f42n[t]*\((\(-\(3\/8\)\) \@\(5\/\(2\ \[Pi]\)\)\ \((5 + 
                        7\ Cos[2\ theta])\)\ Sin[2\ phi]\ Sin[theta]\^2)\) + 
              f44[t]*\((3\/8\ \@\(35\/\(2\ \[Pi]\)\)\ Cos[
                      4\ phi]\ Sin[theta]\^4)\) + 
              f44n[t]*\((\(-\(3\/8\)\)\ \ \@\(35\/\(2\ \[Pi]\)\)\ Sin[
                      4\ phi]\ Sin[theta]\^4)\);\), "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        StyleBox[\( (*\ inclination\ angle\ *) \),
          FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(angle[tt_] := 
            Re[phi0 /. 
                FindRoot[
                  First[\((\(-\(1\/2\)\)\ \@\(5\/\(2\ \[Pi]\)\)\ \((2\ \@3\ \
Cos[2\ phi0]\ f22n[t] - 3\ Cos[2\ phi0]\ f42n[t] + 
                                  3\ \@7\ Cos[4\ phi0]\ f44n[t] + 
                                  2\ \@3\ f22[t]\ Sin[2\ phi0] - 
                                  3\ f42[t]\ Sin[2\ phi0] + 
                                  3\ \@7\ f44[t]\ Sin[4\ phi0])\) /. evol)\) /. 
                        t \[Rule] tt] \[Equal] 0, \ {phi0, Pi/4}]];\), 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        StyleBox[\( (*\ 
            deformation\ in\ the\ flow\ plane\ \((Taylor\ def)\)*) \),
          FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(rmax[t_] := r[Pi/2, angle[t]];\), 
        "\[IndentingNewLine]", \(rmin[t_] := r[Pi/2, angle[t] + Pi/2];\), 
        "\[IndentingNewLine]", \(DefXY[
              t_] := \((rmax[t] - rmin[t])\)/\((rmax[t] + rmin[t])\);\), 
        "\[IndentingNewLine]"}]}]], "Input"],

Cell[BoxData[
    \(Null\^5\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ PUT\ the\ values\ of\ your\ parameters\ here\ *) \),
        FontSize->14,
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", \( (*\ 
        flow\ rotation\ component\ \ [shear\ flow\  \[Rule] \ sc = 1, \ 
            straining\ flow\  \[Rule] sc = 0]*) \), "\[IndentingNewLine]", 
      RowBox[{
        StyleBox[\(sc = 1;\),
          FontColor->RGBColor[0, 0, 1]], 
        "\[IndentingNewLine]", \( (*\ elasticity\ *) \), 
        StyleBox["\[IndentingNewLine]",
          FontColor->RGBColor[0, 0, 1]], 
        RowBox[{
          StyleBox[\(El = 1\),
            FontColor->RGBColor[0, 0, 1]], ";"}], 
        "\[IndentingNewLine]", \( (*\ Capillary\ number\ *) \), 
        "\[IndentingNewLine]", 
        RowBox[{
          StyleBox[\(Ca = 0.1\),
            FontColor->RGBColor[0, 0, 1]], ";"}], 
        "\[IndentingNewLine]", \( (*\ viscosity\ ratio\ *) \), 
        "\[IndentingNewLine]", 
        RowBox[{
          StyleBox[\(vis = 1\),
            FontColor->RGBColor[0, 0, 1]], ";"}], 
        "\[IndentingNewLine]", \(lu1 = vis + 1;\), 
        "\[IndentingNewLine]", \( (*\ end\ time\ *) \), "\[IndentingNewLine]",
         
        RowBox[{
          StyleBox[\(tend = 10\),
            FontColor->RGBColor[0, 0, 1]], ";"}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(evol = 
            NDSolve[{\(f20'\)[t] \[Equal] eqF20f, \(f22'\)[t] \[Equal] 
                  eqF22f, \(f22n'\)[t] \[Equal] eqF22nf, \(f40'\)[t] \[Equal] 
                  eqF40f, \(f42'\)[t] \[Equal] eqF42f, \(f42n'\)[t] \[Equal] 
                  eqF42nf, \(f44'\)[t] \[Equal] eqF44f, \(f44n'\)[t] \[Equal] 
                  eqF44nf, \(g20'\)[t] \[Equal] eqG20f, \(g22'\)[t] \[Equal] 
                  eqG22f, \(g22n'\)[t] \[Equal] eqG22nf, \(g42'\)[t] \[Equal] 
                  eqG42f, \(g42n'\)[t] \[Equal] eqG42nf, \(g40'\)[t] \[Equal] 
                  eqG40f, \(g44'\)[t] \[Equal] eqG44f, \(g44n'\)[t] \[Equal] 
                  eqG44nf, f20[0] \[Equal] 0, f22[0] \[Equal] 0, 
                f22n[0] \[Equal] 0, f40[0] \[Equal] 0, f42[0] \[Equal] 0, 
                f42n[0] \[Equal] 0, f44[0] \[Equal] 0, f44n[0] \[Equal] 0, 
                g20[0] \[Equal] 0, g22[0] \[Equal] 0, g22n[0] \[Equal] 0, 
                g40[0] \[Equal] 0, g42[0] \[Equal] 0, g42n[0] \[Equal] 0, 
                g44[0] \[Equal] 0, g44n[0] \[Equal] 0}, {f20[t], f22[t], 
                f22n[t], f40[t], f42[t], f42n[t], f44[t], f44n[t], g20[t], 
                g22[t], g22n[t], g40[t], g42[t], g42n[t], g44[t], 
                g44n[t]}, {t, 0, tend}];\)}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{\ \((f22n[t])\) /. evol}, \ {t, 0, tend}\ , 
      PlotStyle \[Rule] Hue[0], \ PlotRange \[Rule] All]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.60332 3.77157 [
[.21429 .59082 -3 -9 ]
[.21429 .59082 3 0 ]
[.40476 .59082 -3 -9 ]
[.40476 .59082 3 0 ]
[.59524 .59082 -3 -9 ]
[.59524 .59082 3 0 ]
[.78571 .59082 -3 -9 ]
[.78571 .59082 3 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[.01131 .03758 -30 -4.5 ]
[.01131 .03758 0 4.5 ]
[.01131 .13187 -36 -4.5 ]
[.01131 .13187 0 4.5 ]
[.01131 .22616 -24 -4.5 ]
[.01131 .22616 0 4.5 ]
[.01131 .32045 -36 -4.5 ]
[.01131 .32045 0 4.5 ]
[.01131 .41474 -30 -4.5 ]
[.01131 .41474 0 4.5 ]
[.01131 .50903 -36 -4.5 ]
[.01131 .50903 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(2)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(4)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(6)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(8)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(10)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07143 .60332 m
.07143 .60707 L
s
.11905 .60332 m
.11905 .60707 L
s
.16667 .60332 m
.16667 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.30952 .60332 m
.30952 .60707 L
s
.35714 .60332 m
.35714 .60707 L
s
.45238 .60332 m
.45238 .60707 L
s
.5 .60332 m
.5 .60707 L
s
.54762 .60332 m
.54762 .60707 L
s
.64286 .60332 m
.64286 .60707 L
s
.69048 .60332 m
.69048 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.83333 .60332 m
.83333 .60707 L
s
.88095 .60332 m
.88095 .60707 L
s
.92857 .60332 m
.92857 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
.02381 .03758 m
.03006 .03758 L
s
[(-0.15)] .01131 .03758 1 0 Mshowa
.02381 .13187 m
.03006 .13187 L
s
[(-0.125)] .01131 .13187 1 0 Mshowa
.02381 .22616 m
.03006 .22616 L
s
[(-0.1)] .01131 .22616 1 0 Mshowa
.02381 .32045 m
.03006 .32045 L
s
[(-0.075)] .01131 .32045 1 0 Mshowa
.02381 .41474 m
.03006 .41474 L
s
[(-0.05)] .01131 .41474 1 0 Mshowa
.02381 .50903 m
.03006 .50903 L
s
[(-0.025)] .01131 .50903 1 0 Mshowa
.125 Mabswid
.02381 .05644 m
.02756 .05644 L
s
.02381 .0753 m
.02756 .0753 L
s
.02381 .09416 m
.02756 .09416 L
s
.02381 .11302 m
.02756 .11302 L
s
.02381 .15073 m
.02756 .15073 L
s
.02381 .16959 m
.02756 .16959 L
s
.02381 .18845 m
.02756 .18845 L
s
.02381 .2073 m
.02756 .2073 L
s
.02381 .24502 m
.02756 .24502 L
s
.02381 .26388 m
.02756 .26388 L
s
.02381 .28274 m
.02756 .28274 L
s
.02381 .30159 m
.02756 .30159 L
s
.02381 .33931 m
.02756 .33931 L
s
.02381 .35817 m
.02756 .35817 L
s
.02381 .37703 m
.02756 .37703 L
s
.02381 .39588 m
.02756 .39588 L
s
.02381 .4336 m
.02756 .4336 L
s
.02381 .45246 m
.02756 .45246 L
s
.02381 .47131 m
.02756 .47131 L
s
.02381 .49017 m
.02756 .49017 L
s
.02381 .52789 m
.02756 .52789 L
s
.02381 .54675 m
.02756 .54675 L
s
.02381 .5656 m
.02756 .5656 L
s
.02381 .58446 m
.02756 .58446 L
s
.02381 .01873 m
.02756 .01873 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02846 .49518 L
.03279 .41205 L
.03793 .33149 L
.04262 .27241 L
.0522 .18368 L
.05746 .14873 L
.06244 .12242 L
.06754 .10085 L
.07295 .08272 L
.08265 .05927 L
.08804 .04996 L
.09308 .04302 L
.09862 .03697 L
.10458 .03191 L
.11468 .02581 L
.1204 .02337 L
.12571 .02159 L
.13544 .01922 L
.14087 .01827 L
.1458 .01758 L
.15068 .01703 L
.15583 .01656 L
.16505 .01594 L
.17018 .01569 L
.17498 .0155 L
.18019 .01534 L
.18587 .0152 L
.1913 .01509 L
.19632 .01502 L
.20103 .01496 L
.20622 .01491 L
.21522 .01484 L
.22015 .01481 L
.22478 .01479 L
.23461 .01476 L
.23955 .01475 L
.24496 .01474 L
.2496 .01474 L
.25455 .01473 L
.25888 .01473 L
.26347 .01473 L
.2688 .01472 L
.27371 .01472 L
.279 .01472 L
.28481 .01472 L
.28983 .01472 L
.29522 .01472 L
.30031 .01472 L
.30496 .01472 L
Mistroke
.30975 .01472 L
.31484 .01472 L
.31964 .01472 L
.32399 .01472 L
.32666 .01472 L
.32912 .01472 L
.33177 .01472 L
.33467 .01472 L
.3372 .01472 L
.33956 .01472 L
.34206 .01472 L
.34345 .01472 L
.34473 .01472 L
.34583 .01472 L
.34702 .01472 L
.34832 .01472 L
.34955 .01472 L
.35085 .01472 L
.3515 .01472 L
.35222 .01472 L
.35349 .01472 L
.35466 .01472 L
.35586 .01472 L
.35699 .01472 L
.35911 .01472 L
.36385 .01472 L
.38462 .01472 L
.40298 .01472 L
.4134 .01472 L
.42314 .01472 L
.43355 .01472 L
.44306 .01472 L
.45321 .01472 L
.46411 .01472 L
.47335 .01472 L
.48317 .01472 L
.48829 .01472 L
.49395 .01472 L
.50393 .01472 L
.50883 .01472 L
.51151 .01472 L
.514 .01472 L
.51631 .01472 L
.51842 .01472 L
.51962 .01472 L
.52075 .01472 L
.52325 .01472 L
.53337 .01472 L
.53891 .01472 L
.54162 .01472 L
Mistroke
.5428 .01472 L
.5441 .01472 L
.54532 .01472 L
.54645 .01472 L
.54753 .01472 L
.54868 .01472 L
.54932 .01472 L
.55001 .01472 L
.55127 .01472 L
.55361 .01472 L
.55871 .01472 L
.56408 .01472 L
.57369 .01472 L
.58253 .01472 L
.59274 .01472 L
.59776 .01472 L
.60241 .01472 L
.61109 .01472 L
.61566 .01472 L
.62052 .01472 L
.64005 .01472 L
.65012 .01472 L
.6554 .01472 L
.66097 .01472 L
.66582 .01472 L
.67113 .01472 L
.67596 .01472 L
.68045 .01472 L
.68509 .01472 L
.68929 .01472 L
.69163 .01472 L
.69415 .01472 L
.69874 .01472 L
.70902 .01472 L
.71159 .01472 L
.71404 .01472 L
.71863 .01472 L
.72094 .01472 L
.72346 .01472 L
.72865 .01472 L
.73142 .01472 L
.73437 .01472 L
.73968 .01472 L
.75 .01472 L
.75581 .01472 L
.76114 .01472 L
.76583 .01472 L
.77097 .01472 L
.77356 .01472 L
.77633 .01472 L
Mistroke
.78133 .01472 L
.78391 .01472 L
.78664 .01472 L
.78897 .01472 L
.79154 .01472 L
.79298 .01472 L
.7943 .01472 L
.79571 .01472 L
.79726 .01472 L
.80001 .01472 L
.80263 .01472 L
.80523 .01472 L
.80768 .01472 L
.80904 .01472 L
.8105 .01472 L
.81307 .01472 L
.81552 .01472 L
.81812 .01472 L
.82033 .01472 L
.82276 .01472 L
.82527 .01472 L
.828 .01472 L
.83296 .01472 L
.84226 .01472 L
.84753 .01472 L
.85312 .01472 L
.86317 .01472 L
.87254 .01472 L
.88264 .01472 L
.90091 .01472 L
.90593 .01472 L
.91129 .01472 L
.91635 .01472 L
.92094 .01472 L
.92343 .01472 L
.92613 .01472 L
.92867 .01472 L
.93102 .01472 L
.93233 .01472 L
.93357 .01472 L
.93492 .01472 L
.93637 .01472 L
.9371 .01472 L
.93789 .01472 L
.93864 .01472 L
.93933 .01472 L
.94064 .01472 L
.94138 .01472 L
.94204 .01472 L
.94307 .01472 L
Mistroke
.94403 .01472 L
.9462 .01472 L
.95059 .01472 L
.95463 .01472 L
.95845 .01472 L
.9606 .01472 L
.96181 .01472 L
.96294 .01472 L
.96388 .01472 L
.96492 .01472 L
.966 .01472 L
.96702 .01472 L
.96814 .01472 L
.96932 .01472 L
.97033 .01472 L
.97143 .01472 L
.9739 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`009`3oool0
0`000000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`009`3oool00`000000
oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`0T0?oool/0o`001`3oool002L0oooo0P00
000I0?ooo``0o`00dP3oool002L0oooo00<000000?ooo`3oool05P3oool20?l00=h0oooo000W0?oo
o`030000003oool0oooo01@0oooo0P3o003P0?ooo`003P3oool2000000@0oooo00<000000?ooo`3o
ool00P3oool400000080oooo0`0000050?ooo`030000003oool0oooo0180oooo0P3o003R0?ooo`00
3@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo0>80oooo000=0?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`80
00004@3oool00`3o0000oooo0?ooo`3S0?ooo`001`3oool400000080oooo00@000000?ooo`3oool0
00002P3oool010000000oooo0?ooo`3oool3000000D0oooo00<000000?ooo`3oool03`3oool00`3o
0000oooo0?ooo`3T0?ooo`003@3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo
0?ooo`0000001`3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0>D0oooo000=0?oo
o`040000003oool0oooo000000P0oooo0`0000030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`3V0?ooo`003P3oool2000000/0oooo00@000000?oo
o`3oool0oooo100000040?ooo`030000003oool0oooo00d0oooo00<0o`000?ooo`3oool0iP3oool0
02L0oooo0P00000=0?ooo`030?l0003oool0oooo0>L0oooo000W0?ooo`030000003oool0oooo00`0
oooo00<0o`000?ooo`3oool0i`3oool002L0oooo00<000000?ooo`3oool0303oool00`3o0000oooo
0?ooo`3W0?ooo`009`3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0>P0oooo000W
0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool0j03oool002L0oooo0P00000;0?oo
o`030?l0003oool0oooo0>T0oooo000W0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3o
ool0j@3oool002L0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`3Z0?ooo`009`3o
ool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo0>X0oooo000W0?ooo`8000002P3oool0
0`3o0000oooo0?ooo`3Z0?ooo`009`3oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo
0>/0oooo000W0?ooo`030000003oool0oooo00P0oooo00<0o`000?ooo`3oool0j`3oool002L0oooo
00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`3[0?ooo`009`3oool00`000000oooo0?oo
o`070?ooo`030?l0003oool0oooo0>`0oooo000W0?ooo`800000203oool00`3o0000oooo0?ooo`3/
0?ooo`009`3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo0>`0oooo000W0?ooo`03
0000003oool0oooo00H0oooo00<0o`000?ooo`3oool0k@3oool000P0oooo0P0000040?ooo`030000
003oool0oooo0080oooo100000020?ooo`@000000P3oool3000000D0oooo00<000000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`3]0?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<0o`000?ooo`3oool0k@3oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool2000000L0
oooo00<0o`000?ooo`3oool0k@3oool000030?ooo`0000000000008000000P3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0`0000050?oo
o`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0k@3oool000L0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000000L0oooo00<00000
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`3^0?ooo`001`3oool010000000oooo0?ooo`000008
0?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`3o0000oooo0?ooo`3^0?ooo`00203oool2000000/0oooo00<00000
0?ooo`3oool00P3oool2000000<0oooo100000040?ooo`030000003oool0oooo00D0oooo00<0o`00
0?ooo`3oool0kP3oool002L0oooo0P0000060?ooo`030?l0003oool0oooo0>h0oooo000W0?ooo`03
0000003oool0oooo00D0oooo00<0o`000?ooo`3oool0kP3oool002L0oooo00<000000?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`3^0?ooo`009`3oool00`000000oooo0?ooo`050?ooo`030?l0003o
ool0oooo0>h0oooo000W0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0k`3oool0
02L0oooo0P0000050?ooo`030?l0003oool0oooo0>l0oooo000W0?ooo`030000003oool0oooo00@0
oooo00<0o`000?ooo`3oool0k`3oool002L0oooo00<000000?ooo`3oool0103oool00`3o0000oooo
0?ooo`3_0?ooo`009`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo0>l0oooo000W
0?ooo`8000001@3oool00`3o0000oooo0?ooo`3_0?ooo`009`3oool00`000000oooo0?ooo`040?oo
o`030?l0003oool0oooo0>l0oooo000W0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0k`3oool002L0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`3`0?ooo`009`3o
ool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0?00oooo000W0?ooo`800000103oool0
0`3o0000oooo0?ooo`3`0?ooo`009`3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo
0?00oooo000W0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0l03oool001@0oooo
0P0000040?ooo`030000003oool0oooo0080oooo100000040?ooo`030000003oool0oooo00<0oooo
00<0o`000?ooo`3oool0l03oool001<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0l03oool001<0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`800000103oool00`3o0000oooo
0?ooo`3`0?ooo`003@3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0l@3oool001<0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<0o`000?ooo`3oool0l@3oool001<0oooo00@000000?ooo`3oool00000203oool3000000D0oooo
00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3a0?ooo`00503oool2000000/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo0?40oooo000W
0?ooo`8000000`3oool00`3o0000oooo0?ooo`3a0?ooo`009`3oool00`000000oooo0?ooo`020?oo
o`030?l0003oool0oooo0?40oooo000W0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3o
ool0l@3oool002L0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3a0?ooo`009`3o
ool01@000000oooo0?ooo`3oool0o`000?@0oooo000W0?ooo`8000000P3oool00`3o0000oooo0?oo
o`3b0?ooo`009`3oool01@000000oooo0?ooo`3oool0o`000?@0oooo000W0?ooo`050000003oool0
oooo0?ooo`3o0000m03oool002L0oooo00D000000?ooo`3oool0oooo0?l0003d0?ooo`009`3oool2
00000080oooo00<0o`000?ooo`3oool0lP3oool002L0oooo00D000000?ooo`3oool0oooo0?l0003d
0?ooo`009`3oool01@000000oooo0?ooo`3oool0o`000?@0oooo000W0?ooo`050000003oool0oooo
0?ooo`3o0000m03oool002L0oooo00D000000?ooo`3oool0oooo0?l0003d0?ooo`009`3oool20000
0080oooo00<0o`000?ooo`3oool0lP3oool002L0oooo00@000000?ooo`3oool0o`00m@3oool002L0
oooo00@000000?ooo`3oool0o`00m@3oool000P0oooo0P0000040?ooo`030000003oool0oooo00<0
oooo0P0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`040000003oool0oooo0?l0
0?D0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0o`00m@3o
ool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000000030?ooo`3o0000oooo0?@0oooo
00000`3oool000000000000200000080oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo0?ooo`<000001@3oool010000000oooo0?ooo`3o003e
0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo00@0
00000?ooo`3oool000001`3oool010000000oooo0?ooo`3o003e0?ooo`001`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`050?ooo`040000003oool0oooo0?l00?D0oooo00080?ooo`8000002P3oool2
000000<0oooo100000020?ooo`@00000103oool010000000oooo0?ooo`3o003e0?ooo`009`3oool2
000000030?ooo`3o0000oooo0?@0oooo000W0?ooo`040000003oool0oooo0?l00?D0oooo000W0?oo
o`040000003oool0oooo0?l00?D0oooo000W0?ooo`040000003oool0oooo0?l00?D0oooo000W0?oo
o`040000003oool0oooo0?l00?D0oooo000W0?ooo`80000000<0oooo0?l0003oool0m03oool002L0
oooo00@000000?ooo`3oool0o`00m@3oool002L0oooo00@000000?ooo`3oool0o`00m@3oool002L0
oooo00@000000?ooo`3oool0o`00m@3oool002L0oooo0P0000000`3o0000oooo0?ooo`3d0?ooo`00
9`3oool00`000000oooo0?l0003f0?ooo`009`3oool00`000000oooo0?l0003f0?ooo`009`3oool0
0`000000oooo0?l0003f0?ooo`009`3oool00`000000oooo0?l0003f0?ooo`009`3oool200000003
0?l0003oool0oooo0?@0oooo000W0?ooo`030000003oool0o`000?H0oooo000W0?ooo`030000003o
ool0o`000?H0oooo000>0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3oool3
000000D0oooo00<000000?ooo`3o0000mP3oool000d0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o0000mP3o
ool000d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo0080oooo0P0000000`3o0000oooo0?ooo`3d0?ooo`001`3oool400000080oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`<000001@3oool00`000000
oooo0?l0003f0?ooo`003@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?l0003f0?ooo`003@3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?l0003f0?ooo`003P3oool2000000X0oooo0P0000030?ooo`@00000103oool00`00
0000oooo0?l0003f0?ooo`009`3oool2000000030?l0003oool0oooo0?@0oooo000W0?ooo`030000
003oool0o`000?H0oooo000W0?ooo`030000003oool0o`000?H0oooo000W0?ooo`030000003oool0
o`000?H0oooo000W0?ooo`80000000<0o`000?ooo`3oool0m03oool002L0oooo00<000000?l0003o
ool0mP3oool002L0oooo00<000000?l0003oool0mP3oool002L0oooo00<000000?l0003oool0mP3o
ool002L0oooo00<000000?l0003oool0mP3oool002L0oooo00<000000?l0003oool0mP3oool002L0
oooo00<000000?l0003oool0mP3oool002L0oooo00<000000?l0003oool0mP3oool002L0oooo00<0
00000?l0003oool0mP3oool002L0oooo00<000000?l0003oool0mP3oool002L0oooo00<000000?l0
003oool0mP3oool002L0oooo00<000000?l0003oool0mP3oool002L0oooo00<000000?l0003oool0
mP3oool000P0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`@000000P3o
ool3000000D0oooo00<000000?l0003oool0mP3oool000L0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000o`000?ooo`3f0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`03
0000003o0000oooo0?H0oooo00000`3oool000000000000200000080oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0?ooo`<000001@3oool0
0`000000o`000?ooo`3f0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000000D0oooo00@000000?ooo`3oool000001`3oool00`000000o`000?ooo`3f0?ooo`001`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`050?ooo`030000003o0000oooo0?H0oooo00080?ooo`80
00002P3oool2000000@0oooo0P0000030?ooo`@00000103oool00`000000o`000?ooo`3f0?ooo`00
9`3oool00`000000o`000?ooo`3f0?ooo`009`3oool00`000000o`000?ooo`3f0?ooo`009`3oool0
0`000000o`000?ooo`3f0?ooo`009`3oool00`000000o`000?ooo`3f0?ooo`009`3oool00`000000
o`000?ooo`3f0?ooo`009`3oool00`000000o`000?ooo`3f0?ooo`009`3oool00`3o0000oooo0?oo
o`3f0?ooo`009`3oool00`3o0000oooo0?ooo`3f0?ooo`009`3oool00`3o0000oooo0?ooo`3f0?oo
o`009`3oool00`3o000000000?ooo`0[0?ooo`@00000;P3oool00`000000oooo0?ooo`0]0?ooo`80
0000;P3oool2000002X0oooo100000030?ooo`800000103oool002L0oooo00<0o`000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02`0oooo00@000000?ooo`3oool0
0000;03oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`010?ooo`009`3oool00`3o0000oooo0?ooo`0/0?ooo`030000003oool0oooo
02/0oooo1@00000]0?ooo`040000003oool0oooo000002`0oooo00@000000?ooo`3oool00000:`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3oool002L0oooo00<0
o`000?ooo`3oool0;@3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo000002h0oooo
0`00000^0?ooo`800000;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool00@3oool002L0oooo00<0o`000?ooo`3oool0;P3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0000002h0oooo00<000000?ooo`3oool0;@3oool010000000oooo0?ooo`00000[0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`010?ooo`009`3oool00`3o0000
00000?ooo`0[0?ooo`040000003oool0oooo000002d0oooo0P00000^0?ooo`030000003oool0oooo
02d0oooo00@000000?ooo`3oool00000:@3oool3000000<0oooo00@000000?ooo`3oool000000`3o
ool002L0oooo00<0o`000?ooo`3oool0;03oool2000002l0oooo00<000000?ooo`3oool0;@3oool3
000002d0oooo0P00000/0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`009`3oool00`3o
0000oooo0?ooo`3f0?ooo`009`3oool00`3o0000oooo0?ooo`3f0?ooo`009`3oool00`3o0000oooo
0?ooo`3f0?ooo`008@3oool6000000030?l00000000000000?H00000000W0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`009`3oool00`00
0000oooo0?ooo`3f0?ooo`009`3oool00`000000oooo0?ooo`3f0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3o
oolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.62025, -0.17043, 0.04136, \
0.0010444}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Ca\)], "Input"],

Cell[BoxData[
    \(0.1`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(x22n0\)], "Input"],

Cell[BoxData[
    \(\(-0.14657679632100967`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{\ DefXY[t] /. evol}, \ {t, 0, tend}\ , 
      PlotStyle \[Rule] Hue[0], \ PlotRange \[Rule] {0, 0.2}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 1.61546e-17 3.09017 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -30 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -24 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -30 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -18 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07725 m
.03006 .07725 L
s
[(0.025)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(0.05)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(0.075)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.1)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.125)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.15)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.175)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(0.2)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 0 m
.04262 .06053 L
.06244 .11283 L
.08426 .15864 L
.10458 .19196 L
.12297 .21559 L
.14264 .23512 L
.16394 .25077 L
.17372 .25633 L
.18408 .26128 L
.19359 .26505 L
.20406 .26844 L
.21351 .27089 L
.2225 .27274 L
.23263 .27435 L
.2419 .27541 L
.24708 .27586 L
.25189 .27618 L
.25716 .27646 L
.26011 .27657 L
.26278 .27665 L
.26511 .2767 L
.26644 .27673 L
.26766 .27675 L
.26894 .27676 L
.2696 .27677 L
.27032 .27677 L
.2716 .27678 L
.27281 .27678 L
.27391 .27678 L
.27513 .27678 L
.2764 .27677 L
.2776 .27676 L
.27973 .27673 L
.28203 .27669 L
.28456 .27663 L
.28732 .27656 L
.29289 .27637 L
.30285 .2759 L
.32246 .27462 L
.34341 .27292 L
.38491 .26922 L
.42489 .26588 L
.46336 .26326 L
.48284 .26219 L
.50428 .26123 L
.52463 .2605 L
.54368 .25998 L
.55409 .25975 L
.56397 .25958 L
Mistroke
.57369 .25944 L
.5825 .25933 L
.59211 .25925 L
.59739 .25922 L
.60235 .25919 L
.60459 .25918 L
.60696 .25917 L
.609 .25917 L
.61119 .25916 L
.61243 .25916 L
.61355 .25916 L
.61469 .25916 L
.61575 .25916 L
.61698 .25915 L
.61763 .25915 L
.61832 .25915 L
.61947 .25915 L
.62075 .25915 L
.62197 .25915 L
.62311 .25915 L
.62435 .25916 L
.62568 .25916 L
.6284 .25916 L
.63087 .25917 L
.63564 .25918 L
.64013 .2592 L
.65015 .25925 L
.661 .25932 L
.68092 .2595 L
.70197 .25975 L
.73991 .26026 L
.78031 .26085 L
.81918 .26138 L
.83897 .26161 L
.86051 .26183 L
.87943 .26198 L
.8902 .26206 L
.90032 .26211 L
.91062 .26216 L
.92007 .26219 L
.9249 .26221 L
.93018 .26222 L
.93548 .26223 L
.93838 .26223 L
.94107 .26224 L
.94222 .26224 L
.94343 .26224 L
.94448 .26224 L
.94561 .26224 L
.94682 .26224 L
Mistroke
.94795 .26224 L
.94864 .26224 L
.9493 .26224 L
.95053 .26224 L
.9516 .26224 L
.95275 .26224 L
.95383 .26224 L
.9548 .26224 L
.9572 .26224 L
.95947 .26224 L
.96365 .26223 L
.9675 .26222 L
.97619 .26221 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00D03oool400000300oooo00<000000?ooo`3oool0;@3oool200000300
oooo0P00000[0?ooo`@000000`3oool2000000@0oooo001@0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0;03oool010000000oooo0?ooo`00000^0?ooo`040000003oool0oooo0000
02`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0040oooo001A0?oo
o`030000003oool0oooo02d0oooo1@00000]0?ooo`040000003oool0oooo000002h0oooo00@00000
0?ooo`3oool00000;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0@3oool00580oooo00<000000?ooo`3oool0;03oool010000000oooo0?ooo`00000^0?ooo`<00000
<03oool2000002d0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0040
oooo001C0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`000000;P3oool00`000000oooo
0?ooo`0_0?ooo`040000003oool0oooo000002`0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0040oooo001@0?ooo`040000003oool0oooo000002l0oooo0P00000^0?oo
o`030000003oool0oooo02l0oooo00@000000?ooo`3oool00000:P3oool3000000<0oooo00@00000
0?ooo`3oool000000`3oool00540oooo0P00000a0?ooo`030000003oool0oooo02d0oooo0`00000_
0?ooo`800000;@3oool00`000000oooo0?ooo`020?ooo`800000103oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool001/0oooo1P0000000`3o000000000000003k00000040oooo000Q
0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`05
0?ooo`008@3oool00`000000o`000?ooo`3l0?ooo`008@3oool00`000000o`000?ooo`3l0?ooo`00
8@3oool00`000000o`000?ooo`3l0?ooo`008@3oool00`000000oooo0?l0003l0?ooo`008@3oool0
0`000000oooo0?l0003l0?ooo`008@3oool00`000000oooo0?l0003l0?ooo`008@3oool200000003
0?ooo`3o0000oooo0?X0oooo000Q0?ooo`040000003oool0oooo0?l00?/0oooo000Q0?ooo`040000
003oool0oooo0?l00?/0oooo000Q0?ooo`050000003oool0oooo0?ooo`3o0000nP3oool00240oooo
0P0000020?ooo`030?l0003oool0oooo0?P0oooo000Q0?ooo`050000003oool0oooo0?ooo`3o0000
nP3oool00240oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`3g0?ooo`008@3oool0
0`000000oooo0?ooo`020?ooo`030?l0003oool0oooo0?L0oooo000Q0?ooo`8000000`3oool00`3o
0000oooo0?ooo`3g0?ooo`008@3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0?H0
oooo00020?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000000`3oool400000080oooo
0`0000050?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0mP3oool000050?ooo`00
0000oooo0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo0?H0
oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0`0000040?ooo`030?l0003oool0oooo
0?D0oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103oool0
10000000oooo0?ooo`3oool3000000D0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?oo
o`3e0?ooo`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000D0oooo
00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo0?D0
oooo00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`3d0?ooo`000P3oool2000000X0oooo0P0000040?ooo`8000000`3oool40000
00@0oooo0P0000060?ooo`030?l0003oool0oooo0?@0oooo000Q0?ooo`030000003oool0oooo00H0
oooo00<0o`000?ooo`3oool0l`3oool00240oooo00<000000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`3c0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo0?<0oooo000Q
0?ooo`800000203oool00`3o0000oooo0?ooo`3b0?ooo`008@3oool00`000000oooo0?ooo`070?oo
o`030?l0003oool0oooo0?80oooo000Q0?ooo`030000003oool0oooo00L0oooo00<0o`000?ooo`3o
ool0lP3oool00240oooo00<000000?ooo`3oool0203oool00`3o0000oooo0?ooo`3a0?ooo`008@3o
ool2000000T0oooo00<0o`000?ooo`3oool0l@3oool00240oooo00<000000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`3`0?ooo`008@3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo
0?00oooo000Q0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0k`3oool00240oooo
0P00000;0?ooo`030?l0003oool0oooo0>l0oooo000Q0?ooo`030000003oool0oooo00/0oooo00<0
o`000?ooo`3oool0kP3oool000P0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P000003
0?ooo`<000001@3oool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0>h0oooo00070?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo00<0o`000?ooo`3oool0k@3oool000L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo
0`00000<0?ooo`030?l0003oool0oooo0>d0oooo00070?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool3000000D0oooo00<000000?ooo`3oool03@3oool00`3o0000
oooo0?ooo`3/0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo
0>/0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0j`3oool0
00P0oooo0P00000:0?ooo`8000000`3oool4000000@0oooo0P00000@0?ooo`030?l0003oool0oooo
0>X0oooo000Q0?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3oool0jP3oool00240oooo
00<000000?ooo`3oool0403oool00`3o0000oooo0?ooo`3Y0?ooo`008@3oool00`000000oooo0?oo
o`0@0?ooo`030?l0003oool0oooo0>T0oooo000Q0?ooo`8000004P3oool00`3o0000oooo0?ooo`3X
0?ooo`008@3oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo0>P0oooo000Q0?ooo`03
0000003oool0oooo0180oooo00<0o`000?ooo`3oool0i`3oool00240oooo00<000000?ooo`3oool0
4`3oool00`3o0000oooo0?ooo`3V0?ooo`008@3oool2000001D0oooo00<0o`000?ooo`3oool0i@3o
ool00240oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`3U0?ooo`008@3oool00`00
0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo0>@0oooo000Q0?ooo`030000003oool0oooo01H0
oooo00<0o`000?ooo`3oool0h`3oool00240oooo0P00000H0?ooo`030?l0003oool0oooo0>80oooo
000Q0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0h@3oool00080oooo0P000004
0?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo0080oooo0`000005
0?ooo`030000003oool0oooo01T0oooo00<0o`000?ooo`3oool0h03oool000050?ooo`000000oooo
0?ooo`000000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0oooo0=l0oooo0000
1@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo0`00000K0?ooo`030?l0003oool0oooo0=h0oooo
00001@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`3oool3000000D0oooo00<000000?ooo`3oool0703oool00`3o0000oooo0?ooo`3M0?oo
o`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo000000D0oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`0M0?ooo`030?l0003oool0oooo0=`0oooo0000
1@3oool000000?ooo`3oool0000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07P3oool20?l00=`0
oooo00020?ooo`8000002P3oool2000000<0oooo100000020?ooo`@00000103oool200000240oooo
00<0o`000?ooo`3oool0f@3oool00240oooo00<000000?ooo`3oool08@3oool20?l00=T0oooo000Q
0?ooo`030000003oool0oooo02<0oooo0P3o003G0?ooo`008@3oool00`000000oooo0?ooo`0U0?oo
o`80o`00EP3ooom90?l003H0oooo000Q0?ooo`800000:03oool00`3o0000oooo0?ooo`100?oooa<0
o`00B@3oool_0?l000L0oooo000Q0?ooo`030000003oool0oooo02P0oooo1@3o000c0?ooo`X0o`00
TP3oool00240oooo00<000000?ooo`3oool0;@3oool50?l002@0oooo2P3o002L0?ooo`008@3oool0
0`000000oooo0?ooo`0b0?ooo`T0o`001P3ooolE0?l00:H0oooo000Q0?ooo`800000?03oool70?l0
0;X0oooo000Q0?ooo`030000003oool0oooo0?`0oooo000Q0?ooo`030000003oool0oooo0?`0oooo
000Q0?ooo`030000003oool0oooo0?`0oooo000Q0?ooo`800000o@3oool00240oooo00<000000?oo
o`3oool0o03oool000h0oooo0P0000040?ooo`030000003oool0oooo0080oooo100000040?ooo`03
0000003oool0oooo0?`0oooo000=0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3l0?ooo`003@3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00<0oooo0`00003l0?ooo`003@3oool010000000oooo0?ooo`00000:0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0o03oool000d0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?`0oooo000=0?ooo`040000
003oool0oooo000000P0oooo0`0000050?ooo`030000003oool0oooo0?`0oooo000>0?ooo`800000
2`3oool00`000000oooo0?ooo`030?ooo`800000o@3oool00240oooo00<000000?ooo`3oool0o03o
ool00240oooo00<000000?ooo`3oool0o03oool00240oooo00<000000?ooo`3oool0o03oool00240
oooo0P00003m0?ooo`008@3oool00`000000oooo0?ooo`3l0?ooo`008@3oool00`000000oooo0?oo
o`3l0?ooo`008@3oool00`000000oooo0?ooo`3l0?ooo`008@3oool200000?d0oooo000Q0?ooo`03
0000003oool0oooo0?`0oooo000Q0?ooo`030000003oool0oooo0?`0oooo000Q0?ooo`030000003o
ool0oooo0?`0oooo000Q0?ooo`800000o@3oool00240oooo00<000000?ooo`3oool0o03oool00080
oooo0P0000040?ooo`030000003oool0oooo0080oooo100000020?ooo`@000000P3oool3000000D0
oooo00<000000?ooo`3oool0o03oool000050?ooo`000000oooo0?ooo`0000002P3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3l0?oo
o`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`<00000o03oool000050?ooo`000000oooo0?oo
o`0000002P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`<000001@3oool0
0`000000oooo0?ooo`3l0?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0
oooo00@0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`3l0?ooo`0000D0oooo
0000003oool0oooo000000080?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0o03oool00080oooo0P00000;0?ooo`030000003o
ool0oooo0080oooo0P0000030?ooo`@00000103oool200000?d0oooo000Q0?ooo`030000003oool0
oooo0?`0oooo000Q0?ooo`030000003oool0oooo0?`0oooo000Q0?ooo`030000003oool0oooo0?`0
oooo000Q0?ooo`800000o@3oool00240oooo00<000000?ooo`3oool0o03oool00240oooo00<00000
0?ooo`3oool0o03oool00240oooo00<000000?ooo`3oool0o03oool00240oooo0P00003m0?ooo`00
8@3oool00`000000oooo0?ooo`3l0?ooo`008@3oool00`000000oooo0?ooo`3l0?ooo`008@3oool0
0`000000oooo0?ooo`3l0?ooo`008@3oool200000?d0oooo000Q0?ooo`030000003oool0oooo0?`0
oooo00080?ooo`800000103oool00`000000oooo0?ooo`020?ooo`@000000P3oool3000000D0oooo
00<000000?ooo`3oool0o03oool000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0o03oool000L0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
0`00003l0?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`040000003oool0oooo0?ooo`<0
00001@3oool00`000000oooo0?ooo`3l0?ooo`001`3oool010000000oooo0?ooo`00000:0?ooo`05
0000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`3l0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`<000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0?`0oooo00080?ooo`8000002`3oool010000000oooo0?ooo`3oool4000000@0oooo0P00003m0?oo
o`008@3oool00`000000oooo0?ooo`3l0?ooo`008@3oool00`000000oooo0?ooo`3l0?ooo`008@3o
ool00`000000oooo0?ooo`3l0?ooo`008@3oool200000?d0oooo000Q0?ooo`030000003oool0oooo
0?`0oooo000Q0?ooo`030000003oool0oooo0?`0oooo000Q0?ooo`030000003oool0oooo0?`0oooo
000Q0?ooo`800000o@3oool00240oooo00<000000?ooo`3oool0o03oool00240oooo00<000000?oo
o`3oool0o03oool00240oooo00<000000?ooo`3oool0o03oool00240oooo0P00003m0?ooo`008@3o
ool00`000000oooo0?ooo`3l0?ooo`000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool4
000000<0oooo00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool0o03oool0
00050?ooo`000000oooo0?ooo`0000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3l0?ooo`0000D0oooo0000
003oool0oooo0000000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`<00000o03oool000050?ooo`000000oooo0?ooo`0000002P3oool0
0`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`<000001@3oool00`000000oooo0?oo
o`3l0?ooo`0000D0oooo0000003oool0oooo0000000:0?ooo`030000003oool0oooo00@0oooo00@0
00000?ooo`3oool000001`3oool00`000000oooo0?ooo`3l0?ooo`0000D0oooo0000003oool0oooo
000000080?ooo`<000000`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0o03oool00080oooo0P00000;0?ooo`040000003oool0oooo0?ooo`@0
00000P3oool4000000@0oooo0P00003m0?ooo`008@3oool00`000000oooo0?ooo`3l0?ooo`008@3o
ool00`000000oooo0?ooo`3l0?ooo`008@3oool00`000000oooo0?ooo`3l0?ooo`008@3oool20000
0?d0oooo000Q0?ooo`030000003oool0oooo0?`0oooo000Q0?ooo`030000003oool0oooo0?`0oooo
000Q0?ooo`030000003oool0oooo0?`0oooo000Q0?ooo`800000o@3oool00240oooo00<000000?oo
o`3oool0o03oool00240oooo00<000000?ooo`3oool0o03oool00240oooo00<000000?ooo`3oool0
o03oool00240oooo0P00003m0?ooo`008@3oool00`000000oooo0?ooo`3l0?ooo`003P3oool20000
00@0oooo00<000000?ooo`3oool00P3oool4000000@0oooo00<000000?ooo`3oool0o03oool000d0
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0?`0oooo000=0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0103oool30000
0?`0oooo000=0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0o`3oool30?oo
o`003@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0?l0oooo0P3oool000d0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00003o0?ooo`@0oooo000>0?oo
o`8000002P3oool200000?l0oooo1@3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.36124, -0.0152823, \
0.0405086, 0.00124846}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{\ angle[t] /. evol}, \ {t, 0, tend}\ , 
      PlotStyle \[Rule] Hue[0], \ PlotRange \[Rule] {0, Pi/4}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 1.33086e-17 0.786905 [
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[.01131 .07869 -18 -4.5 ]
[.01131 .07869 0 4.5 ]
[.01131 .15738 -18 -4.5 ]
[.01131 .15738 0 4.5 ]
[.01131 .23607 -18 -4.5 ]
[.01131 .23607 0 4.5 ]
[.01131 .31476 -18 -4.5 ]
[.01131 .31476 0 4.5 ]
[.01131 .39345 -18 -4.5 ]
[.01131 .39345 0 4.5 ]
[.01131 .47214 -18 -4.5 ]
[.01131 .47214 0 4.5 ]
[.01131 .55083 -18 -4.5 ]
[.01131 .55083 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .07869 m
.03006 .07869 L
s
[(0.1)] .01131 .07869 1 0 Mshowa
.02381 .15738 m
.03006 .15738 L
s
[(0.2)] .01131 .15738 1 0 Mshowa
.02381 .23607 m
.03006 .23607 L
s
[(0.3)] .01131 .23607 1 0 Mshowa
.02381 .31476 m
.03006 .31476 L
s
[(0.4)] .01131 .31476 1 0 Mshowa
.02381 .39345 m
.03006 .39345 L
s
[(0.5)] .01131 .39345 1 0 Mshowa
.02381 .47214 m
.03006 .47214 L
s
[(0.6)] .01131 .47214 1 0 Mshowa
.02381 .55083 m
.03006 .55083 L
s
[(0.7)] .01131 .55083 1 0 Mshowa
.125 Mabswid
.02381 .01574 m
.02756 .01574 L
s
.02381 .03148 m
.02756 .03148 L
s
.02381 .04721 m
.02756 .04721 L
s
.02381 .06295 m
.02756 .06295 L
s
.02381 .09443 m
.02756 .09443 L
s
.02381 .11017 m
.02756 .11017 L
s
.02381 .1259 m
.02756 .1259 L
s
.02381 .14164 m
.02756 .14164 L
s
.02381 .17312 m
.02756 .17312 L
s
.02381 .18886 m
.02756 .18886 L
s
.02381 .2046 m
.02756 .2046 L
s
.02381 .22033 m
.02756 .22033 L
s
.02381 .25181 m
.02756 .25181 L
s
.02381 .26755 m
.02756 .26755 L
s
.02381 .28329 m
.02756 .28329 L
s
.02381 .29902 m
.02756 .29902 L
s
.02381 .3305 m
.02756 .3305 L
s
.02381 .34624 m
.02756 .34624 L
s
.02381 .36198 m
.02756 .36198 L
s
.02381 .37771 m
.02756 .37771 L
s
.02381 .40919 m
.02756 .40919 L
s
.02381 .42493 m
.02756 .42493 L
s
.02381 .44067 m
.02756 .44067 L
s
.02381 .45641 m
.02756 .45641 L
s
.02381 .48788 m
.02756 .48788 L
s
.02381 .50362 m
.02756 .50362 L
s
.02381 .51936 m
.02756 .51936 L
s
.02381 .5351 m
.02756 .5351 L
s
.02381 .56657 m
.02756 .56657 L
s
.02381 .58231 m
.02756 .58231 L
s
.02381 .59805 m
.02756 .59805 L
s
.02381 .61379 m
.02756 .61379 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .61803 m
.06244 .54365 L
.10458 .47595 L
.14415 .42506 L
.18221 .38669 L
.22272 .35576 L
.26171 .3342 L
.28302 .32533 L
.30316 .31857 L
.32144 .31367 L
.34157 .30945 L
.36141 .30635 L
.37239 .30503 L
.38244 .30403 L
.39172 .30329 L
.40184 .30264 L
.4074 .30235 L
.41255 .30212 L
.42272 .30178 L
.4278 .30166 L
.43047 .30161 L
.43329 .30156 L
.43576 .30152 L
.43848 .30149 L
.44094 .30147 L
.44325 .30146 L
.4444 .30145 L
.44566 .30145 L
.44684 .30144 L
.44794 .30144 L
.44893 .30144 L
.45002 .30144 L
.45116 .30144 L
.45223 .30145 L
.4534 .30145 L
.45464 .30145 L
.45686 .30147 L
.45924 .30148 L
.46185 .30151 L
.46714 .30157 L
.47213 .30164 L
.48146 .30182 L
.50241 .30238 L
.54088 .30375 L
.5818 .30537 L
.6212 .30687 L
.65909 .30809 L
.68017 .30865 L
.69943 .30908 L
.71935 .30942 L
Mistroke
.73825 .30966 L
.74787 .30975 L
.75314 .30978 L
.7581 .30981 L
.76274 .30984 L
.76775 .30986 L
.76997 .30986 L
.77231 .30987 L
.77432 .30987 L
.7765 .30988 L
.77783 .30988 L
.77905 .30988 L
.78023 .30988 L
.78147 .30988 L
.78258 .30988 L
.78363 .30988 L
.78477 .30988 L
.786 .30988 L
.78724 .30988 L
.78859 .30988 L
.79131 .30987 L
.79383 .30987 L
.79618 .30986 L
.80083 .30985 L
.80505 .30983 L
.81452 .30978 L
.82453 .30971 L
.83375 .30962 L
.85456 .3094 L
.89401 .30884 L
.93195 .30823 L
.97234 .30758 L
.97619 .30753 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00B03oool400000340oooo00<000000?ooo`3oool0;`3oool200000340
oooo0P00000/0?ooo`@000000`3oool2000000L0oooo00180?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00000_0?ooo`040000003oool0oooo0000
02d0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0oooo00190?oo
o`030000003oool0oooo02h0oooo1@00000_0?ooo`040000003oool0oooo000002l0oooo00@00000
0?ooo`3oool00000;@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
103oool004X0oooo00<000000?ooo`3oool0;@3oool010000000oooo0?ooo`00000`0?ooo`<00000
<@3oool2000002h0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00@0
oooo001;0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`000000<03oool00`000000oooo
0?ooo`0`0?ooo`040000003oool0oooo000002d0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00@0oooo00180?ooo`040000003oool0oooo00000300oooo0P00000`0?oo
o`030000003oool0oooo0300oooo00@000000?ooo`3oool00000:`3oool3000000<0oooo00@00000
0?ooo`3oool000001P3oool004T0oooo0P00000b0?ooo`030000003oool0oooo02l0oooo0`00000`
0?ooo`800000;P3oool00`000000oooo0?ooo`020?ooo`8000001`3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool00140ooooo`00000=000000<0oooo000H0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0203oool001P0
oooo00<000000?ooo`3oool0o`3oool60?ooo`00603oool200000?l0oooo1`3oool001P0oooo00<0
00000?ooo`3oool0o`3oool60?ooo`00603oool00`000000oooo0?ooo`3o0?ooo`H0oooo000H0?oo
o`030000003oool0oooo0?l0oooo1P3oool001P0oooo0P00003o0?ooo`L0oooo000H0?ooo`030000
003oool0oooo0?l0oooo1P3oool001P0oooo00<000000?ooo`3oool0o`3oool60?ooo`00603oool0
0`000000oooo0?ooo`3o0?ooo`H0oooo000H0?ooo`800000o`3oool70?ooo`00603oool00`000000
oooo0?ooo`3o0?ooo`H0oooo000H0?ooo`030000003oool0oooo0?l0oooo1P3oool001P0oooo00<0
00000?ooo`3oool0o`3oool60?ooo`00603oool00`000000oooo0?ooo`3o0?ooo`H0oooo000H0?oo
o`800000o`3oool70?ooo`00603oool00`000000oooo0?ooo`3o0?ooo`H0oooo00040?ooo`800000
103oool00`000000oooo0?ooo`020?ooo`@000001@3oool00`000000oooo0?ooo`3o0?ooo`H0oooo
00030?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`3o0?ooo`H0oooo00030?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
103oool200000?l0oooo1`3oool000<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?l0oooo1P3oool000<0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo1P3oool000<0oooo00@0
00000?ooo`3oool00000203oool3000000H0oooo00<000000?ooo`3oool0o`3oool60?ooo`00103o
ool2000000/0oooo00<000000?ooo`3oool0103oool200000?l0oooo1`3oool001P0oooo00<00000
0?ooo`3oool0o`3oool60?ooo`00603oool00`000000oooo0?ooo`3o0?ooo`H0oooo000H0?ooo`03
0000003oool0oooo0?l0oooo1P3oool001P0oooo0P00003o0?ooo`L0oooo000H0?ooo`030000003o
ool0oooo0?l0oooo1P3oool001P0oooo00<000000?ooo`3oool0o`3oool60?ooo`00603oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo000H0?ooo`800000o`3oool70?ooo`00603oool00`000000oooo
0?ooo`3o0?ooo`H0oooo000H0?ooo`030000003oool0oooo0?l0oooo1P3oool001P0oooo00<00000
0?ooo`3oool0o`3oool60?ooo`00603oool00`000000oooo0?ooo`3o0?ooo`H0oooo000H0?ooo`80
0000o`3oool70?ooo`00603oool00`000000oooo0?ooo`3o0?ooo`H0oooo00040?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`@000001@3oool00`000000oooo0?ooo`3o0?ooo`H0oooo0003
0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?ooo`H0oooo00030?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3o
ool200000?l0oooo1`3oool000<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0oooo1P3oool000<0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo1P3oool000<0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0?l0oooo
1P3oool000@0oooo0P00000:0?ooo`8000001P3oool200000?l0oooo1`3oool001P0oooo00<00000
0?ooo`3oool0o`3oool60?ooo`00603oool00`000000oooo0?ooo`3o0?ooo`H0oooo000H0?ooo`03
0000003oool0oooo0?l0oooo1P3oool001P0oooo0P00003o0?ooo`L0oooo000H0?ooo`030000003o
ool0oooo0?l0oooo1P3oool001P0oooo00<000000?ooo`3oool0o`3oool60?ooo`00603oool00`00
0000oooo0?ooo`3o0?ooo`H0oooo000H0?ooo`800000o`3oool70?ooo`00603oool00`000000oooo
0?ooo`3o0?ooo`H0oooo000H0?ooo`030000003oool0oooo0?l0oooo1P3oool001P0oooo00<00000
0?ooo`3oool0o`3oool60?ooo`00603oool00`000000oooo0?ooo`3o0?ooo`H0oooo000H0?ooo`80
0000o`3oool70?ooo`00603oool00`000000oooo0?ooo`3o0?ooo`H0oooo00040?ooo`800000103o
ool00`000000oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`3o0?ooo`H0oooo0003
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`3o0?ooo`H0oooo00030?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
0`3oool200000?l0oooo1`3oool000<0oooo00@000000?ooo`3oool000002@3oool2000000H0oooo
00<000000?ooo`3oool0o`3oool60?ooo`000`3oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0o`3oool60?ooo`000`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0o`3oool60?ooo`00
103oool2000000X0oooo0P0000060?ooo`800000o`3oool70?ooo`00603oool00`000000oooo0?oo
o`3o0?ooo`H0oooo000H0?ooo`030000003oool0oooo0?l0oooo1P3oool001P0oooo00<000000?oo
o`3oool0o`3oool60?ooo`00603oool200000?l0oooo1`3oool001P0oooo00<000000?ooo`3oool0
o`3oool60?ooo`00603oool00`000000oooo0?ooo`3o0?ooo`H0oooo000H0?ooo`030000003oool0
oooo0?l0oooo1P3oool001P0oooo0P00003o0?ooo`L0oooo000H0?ooo`030000003oool0oooo0?l0
oooo1P3oool001P0oooo00<000000?ooo`3oool0o`3oool60?ooo`00603oool00`000000oooo0?oo
o`3o0?ooo`H0oooo000H0?ooo`030000003oool0oooo0?l0oooo1P3oool001P0oooo0P00001Q0?oo
ob40o`00Q03oool001P0oooo00<000000?ooo`3oool0E03oool<0?l00240oooo5P3o001^0?ooo`00
103oool2000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo04l0oooo1@3o00130?ooof@0o`002P3oool000<0oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04/0oooo103o002f0?ooo`000`3o
ool010000000oooo0?ooo`0000070?ooo`D000001@3oool2000004X0oooo0P3o002j0?ooo`000`3o
ool010000000oooo0?ooo`0000070?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0AP3oool30?l00;`0oooo00030?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`00
00001P3oool00`000000oooo0?ooo`140?ooo`80o`00_`3oool000<0oooo00@000000?ooo`3oool0
00002@3oool2000000H0oooo00<000000?ooo`3oool0@@3oool30?l00<40oooo00040?ooo`800000
2`3oool00`000000oooo0?ooo`040?ooo`800000?`3oool30?l00<@0oooo000H0?ooo`030000003o
ool0oooo03`0oooo0P3o00370?ooo`00603oool00`000000oooo0?ooo`0j0?ooo`80o`00b@3oool0
01P0oooo00<000000?ooo`3oool0>03oool20?l00</0oooo000H0?ooo`800000>03oool00`3o0000
oooo0?ooo`3;0?ooo`00603oool00`000000oooo0?ooo`0e0?ooo`80o`00cP3oool001P0oooo00<0
00000?ooo`3oool0<`3oool20?l00=00oooo000H0?ooo`030000003oool0oooo0380oooo00<0o`00
0?ooo`3oool0d03oool001P0oooo0P00000a0?ooo`80o`00d`3oool001P0oooo00<000000?ooo`3o
ool0;`3oool00`3o0000oooo0?ooo`3C0?ooo`00603oool00`000000oooo0?ooo`0^0?ooo`030?l0
003oool0oooo0=@0oooo000H0?ooo`030000003oool0oooo02`0oooo0P3o003G0?ooo`00603oool2
000002`0oooo00<0o`000?ooo`3oool0e`3oool001P0oooo00<000000?ooo`3oool0:P3oool00`3o
0000oooo0?ooo`3H0?ooo`00603oool00`000000oooo0?ooo`0X0?ooo`80o`00f`3oool000@0oooo
0P0000040?ooo`030000003oool0oooo0080oooo0`0000060?ooo`030000003oool0oooo02L0oooo
00<0o`000?ooo`3oool0f`3oool000<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02H0oooo00<0o`000?ooo`3oool0g03oool000<0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`030?ooo`8000009P3oool00`3o0000oooo
0?ooo`3M0?ooo`000`3oool010000000oooo0?ooo`0000080?ooo`<000001P3oool00`000000oooo
0?ooo`0T0?ooo`030?l0003oool0oooo0=h0oooo00030?ooo`040000003oool0oooo000000P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?ooo`030?l0003oool0oooo0=l0oooo
00030?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0R0?ooo`030?l0003oool0oooo0>00oooo00040?ooo`8000002@3oool4000000D0oooo0P00
000R0?ooo`030?l0003oool0oooo0>40oooo000H0?ooo`030000003oool0oooo0200oooo00<0o`00
0?ooo`3oool0hP3oool001P0oooo00<000000?ooo`3oool07`3oool00`3o0000oooo0?ooo`3S0?oo
o`00603oool00`000000oooo0?ooo`0N0?ooo`030?l0003oool0oooo0>@0oooo000H0?ooo`800000
7P3oool00`3o0000oooo0?ooo`3U0?ooo`00603oool00`000000oooo0?ooo`0L0?ooo`030?l0003o
ool0oooo0>H0oooo000H0?ooo`030000003oool0oooo01/0oooo00<0o`000?ooo`3oool0i`3oool0
01P0oooo00<000000?ooo`3oool06`3oool00`3o0000oooo0?ooo`3W0?ooo`00603oool2000001/0
oooo00<0o`000?ooo`3oool0j03oool001P0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo
0?ooo`3Y0?ooo`00603oool00`000000oooo0?ooo`0H0?ooo`030?l0003oool0oooo0>X0oooo000H
0?ooo`030000003oool0oooo01P0oooo00<0o`000?ooo`3oool0jP3oool001P0oooo0P00000H0?oo
o`030?l0003oool0oooo0>/0oooo000H0?ooo`030000003oool0oooo01H0oooo00<0o`000?ooo`3o
ool0k03oool001P0oooo00<000000?ooo`3oool05@3oool00`3o0000oooo0?ooo`3]0?ooo`00103o
ool2000000@0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool0503o
ool00`3o0000oooo0?ooo`3^0?ooo`000`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0503oool00`3o0000oooo0?ooo`3^0?ooo`000`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000D0oooo0P00000D0?ooo`03
0?l0003oool0oooo0>l0oooo00030?ooo`040000003oool0oooo000000P0oooo0`0000060?ooo`03
0000003oool0oooo0180oooo00<0o`000?ooo`3oool0l03oool000<0oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3o
ool0l@3oool000<0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0140oooo00<0o`000?ooo`3oool0l@3oool000@0oooo0P00000:0?ooo`<00000
1@3oool200000140oooo00<0o`000?ooo`3oool0lP3oool001P0oooo00<000000?ooo`3oool0403o
ool00`3o0000oooo0?ooo`3b0?ooo`00603oool00`000000oooo0?ooo`0?0?ooo`030?l0003oool0
oooo0?<0oooo000H0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0m03oool001P0
oooo0P00000?0?ooo`030?l0003oool0oooo0?@0oooo000H0?ooo`030000003oool0oooo00d0oooo
00<0o`000?ooo`3oool0m@3oool001P0oooo00<000000?ooo`3oool03@3oool00`3o0000oooo0?oo
o`3e0?ooo`00603oool00`000000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0?H0oooo000H0?oo
o`800000303oool00`3o0000oooo0?ooo`3g0?ooo`00603oool00`000000oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo0?L0oooo000H0?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0
n03oool001P0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo0?ooo`3i0?ooo`00603oool2
000000X0oooo00<0o`000?ooo`3oool0n@3oool001P0oooo00<000000?ooo`3oool0203oool00`3o
0000oooo0?ooo`3j0?ooo`00603oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo0?X0
oooo00040?ooo`800000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool00`3o0000oooo0?ooo`3k0?ooo`000`3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`3l0?ooo`000`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo
0P0000070?ooo`030?l0003oool0oooo0?`0oooo00030?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo0?d0oooo
00030?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`030?l0003oool0oooo0?d0oooo00030?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo0?h0
oooo00040?ooo`8000002@3oool4000000D0oooo0P0000050?ooo`030?l0003oool0oooo0?h0oooo
000H0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0o`3oool001P0oooo00<00000
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`3o0?ooo`00603oool00`000000oooo0?ooo`020?oo
o`030?l0003oool0oooo0?l0oooo0@3oool001P0oooo0P0000030?ooo`030?l0003oool0oooo0?l0
oooo0@3oool001P0oooo00D000000?ooo`3oool0oooo0?l0003o0?ooo`@0oooo000H0?ooo`050000
003oool0oooo0?ooo`3o0000o`3oool40?ooo`00603oool010000000oooo0?ooo`3o003o0?ooo`D0
oooo000H0?ooo`80000000<0oooo0?l0003oool0o`3oool40?ooo`00603oool00`000000oooo0?l0
003o0?ooo`H0oooo000H0?ooo`030000003oool0o`000?l0oooo1P3oool001P0oooo00<000000?l0
003oool0o`3oool60?ooo`00603oool00`000000o`000?ooo`3o0?ooo`H0oooo000H0?ooo`030?l0
003oool0oooo0?l0oooo1P3oool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.952658, -0.0588311, \
0.0394232, 0.00477134}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \( (*\ EXPORT\ f[t], \ g[t], \ D[t], \ 
      angle[t]\ in\ data\ file\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(data = Table[0, {i, 1, 101}, {j, 1, 9}];\)\), "\[IndentingNewLine]", 
    \(For[i = 1, 
      i \[LessEqual] 
        101, \ \(i++\), \((\[IndentingNewLine]t = 
          tend/100. *\((i - 1)\); \[IndentingNewLine]data[\([\)\(i, 
            1\)\(]\)] = t; \[IndentingNewLine]data[\([i, 2]\)] = 
          Re[First[f20[t] /. evol]]; \[IndentingNewLine]data[\([i, 3]\)] = 
          Re[First[f22[t] /. evol]]; \[IndentingNewLine]data[\([i, 4]\)] = 
          Re[First[f22n[t] /. evol]]; \[IndentingNewLine]data[\([i, 5]\)] = 
          Re[First[g20[t] /. evol]]; \[IndentingNewLine]data[\([i, 6]\)] = 
          Re[First[g22[t] /. evol]]; \[IndentingNewLine]data[\([i, 7]\)] = 
          Re[First[g22n[t] /. evol]]; \[IndentingNewLine]data[\([i, 8]\)] = 
          Re[First[DefXY[t] /. evol]]; \[IndentingNewLine]data[\([i, 9]\)] = 
          Re[First[
              angle[t] /. 
                evol]];\[IndentingNewLine])\)]\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(SetDirectory["\<~/Desktop/dropdef\>"];\)\), "\[IndentingNewLine]", 
    \(Export["\<dataEvol.dat\>", \ data, \ "\<Table\>"]\)}], "Input"],

Cell[BoxData[
    \("dataEvol.dat"\)], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"],

Cell[BoxData[""], "Input"],

Cell[BoxData[
    \( (*\ STATIONARY\ SHAPES*) \)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      surfactanr\ *) \)\(\[IndentingNewLine]\)\(\(y200 = 
        Ca*y201 + Ca^2*y202 + Ca^3*y203;\)\[IndentingNewLine]
    \(y220 = Ca*y221 + Ca^2*y222 + Ca^3*y223;\)\[IndentingNewLine]
    \(y22n0 = 
        Ca*y22n1 + Ca^2*y22n2 + 
          Ca^3*y22n3;\)\[IndentingNewLine]\[IndentingNewLine]
    \(y400 = Ca*y401 + Ca^2*y402 + Ca^3*y403;\)\[IndentingNewLine]
    \(y420 = Ca*y421 + Ca^2*y422 + Ca^3*y423;\)\[IndentingNewLine]
    \(y42n0 = Ca*y42n1 + Ca^2*y42n2 + Ca^3*y42n3;\)\[IndentingNewLine]
    \(y440 = Ca*y441 + Ca^2*y442 + Ca^3*y443;\)\[IndentingNewLine]
    \(y44n0 = 
        Ca*y44n1 + Ca^2*y44n2 + 
          Ca^3*y44n3;\)\[IndentingNewLine]\[IndentingNewLine]
    \)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      shape\ *) \)\(\[IndentingNewLine]\)\(\(x200 = 
        Ca*x201 + Ca^2*x202 + Ca^3*x203;\)\n
    \(x220 = Ca*x221 + Ca^2*x222 + Ca^3*x223;\)\n
    \(x22n0 = Ca*x22n1 + Ca^2*x22n2 + Ca^3*x22n3;\)\[IndentingNewLine]\n
    \(x400 = Ca*x401 + Ca^2*x402 + Ca^3*x403;\)\n
    \(x420 = Ca*x421 + Ca^2*x422 + Ca^3*x423;\)\n
    \(x42n0 = Ca*x42n1 + Ca^2*x42n2 + Ca^3*x42n3;\)\n
    \(x440 = Ca*x441 + Ca^2*x442 + Ca^3*x443;\)\n
    \(x44n0 = Ca*x44n1 + Ca^2*x44n2 + Ca^3*x44n3;\)\)\)\)], "Input"],

Cell[BoxData[{
    \(\(cap = \((1 + El)\)/Ca;\)\), "\[IndentingNewLine]", 
    \(\(mar = \((El)\)/
          Ca;\)\[IndentingNewLine]\[IndentingNewLine] \
(*\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(----\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(y221 = 0; y201 = 0; y421 = 0; y42n1 = 0; y441 = 0; y44n1 = 0; y401 = 0; 
    x221 = 0; x201 = 0; x421 = 0; x42n1 = 0; x441 = 0; x44n1 = 0; x401 = 0; 
    x22n1 = \(-\@\(\(5\ \[Pi]\)\/6\)\); 
    y22n1 = \(-\(\(\((1 + 
                  2\ El)\)\ \@\(\(5\ \[Pi]\)\/6\)\)\/El\)\);\
\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine] \
(*\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(----\)\)\)\
\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \), "\[IndentingNewLine]", 
    \(y22n2 = 0; 
    y222 = \(\((10\ lu1 + 3\ El\ \((3 + lu1)\) + El\^2\ \((9 + 23\ lu1)\))\)\ \
\@\(\(5\ \[Pi]\)\/6\)\)\/\(12\ El\^2\); 
    y202 = \(-\(\(5\ \((5 + 17\ El)\)\ \@\(5\ \[Pi]\)\)\/\(42\ El\)\)\); 
    x22n2 = 0; y422 = 0; y42n2 = 0; 
    y442 = \(-\(\(5\ \((9 + 
                  4\ El)\)\ \@\(\(5\ \[Pi]\)\/14\)\)\/\(12\ El\)\)\); 
    x222 = \(\((3 + lu1 + El\ \((9 + 23\ lu1)\))\)\ \@\(\(5\ \[Pi]\)\/6\)\)\/\
\(24\ El\); x202 = \(-\(\(5\ \@\(5\ \[Pi]\)\)\/7\)\); y44n2 = 0; 
    x442 = \(-\(5\/4\)\)\ \@\(\(5\ \[Pi]\)\/14\); x422 = 0; x42n2 = 0; 
    x44n2 = 0; x402 = \(5\ \@\[Pi]\)\/28; 
    y402 = \(5\ \((9 + 4\ El)\)\ \@\[Pi]\)\/\(84\ El\);\[IndentingNewLine]\
\[IndentingNewLine] (*\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(----\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(y423 = 0; 
    y42n3 = \(25\ \((278 + 213\ El)\)\ \@\(\(5\ \[Pi]\)\/2\)\)\/\(3234\ El\); 
    y443 = 0; 
    y44n3 = \(-\(\(\((\(-540\)\ lu1 + 2\ El\^3\ \((569 + 1359\ lu1)\) + 
                  El\ \((385 + 2731\ lu1)\) + 
                  El\^2\ \((3133 + 
                        3779\ lu1)\))\)\ \@\(\(5\ \[Pi]\)\/14\)\)\/\(864\ \
El\^3\)\)\); y223 = 0; 
    y22n3 = \(1\/\(14112\ El\^3\)\) \((\((23520\ El\^4 + 9800\ lu1\^2 + 
                98\ El\ \((9 + 96\ lu1 + 31\ lu1\^2)\) + 
                El\^2\ \((\(-18147\) + 12642\ lu1 + 3577\ lu1\^2)\) + 
                El\^3\ \((\(-178191\) + 20286\ lu1 + 
                      25921\ lu1\^2)\))\)\ \@\(\(5\ \[Pi]\)\/6\))\); 
    y203 = 0; x423 = 0; x42n3 = 425\/539\ \@\(\(5\ \[Pi]\)\/2\); x443 = 0; 
    x44n3 = \(-\(\(\((\(-10\)\ \((1 + lu1)\) + El\ \((239 + 109\ lu1)\) + 
                  El\^2\ \((839 + 
                        2049\ lu1)\))\)\ \@\(\(5\ \[Pi]\)\/14\)\)\/\(864\ \
El\^2\)\)\); x223 = 0; 
    x22n3 = \(1\/\(28224\ El\^2\)\) \((\((23520\ El\^3 + 
                980\ lu1\ \((3 + lu1)\) + 
                147\ El\ \((21 + 34\ lu1 + 9\ lu1\^2)\) + 
                El\^2\ \((\(-99711\) + 20286\ lu1 + 
                      25921\ lu1\^2)\))\)\ \@\(\(5\ \[Pi]\)\/6\))\); 
    x203 = 0; x403 = 0; 
    y403 = 0;\[IndentingNewLine] (*\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(--\(\
--\(--\(--\(--\(--\(---\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\)\
\)\)\)\)\)\)\)\)*) \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\)}], "Input"]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 1280}, {0, 800}},
WindowSize->{799, 600},
WindowMargins->{{102, Automatic}, {Automatic, 38}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 134, 2, 27, "Input"],
Cell[1891, 55, 58, 1, 27, "Input"],
Cell[1952, 58, 613, 11, 139, "Input"],

Cell[CellGroupData[{
Cell[2590, 73, 2738, 49, 796, "Input"],
Cell[5331, 124, 41, 1, 28, "Output"]
}, Open  ]],
Cell[5387, 128, 2663, 50, 363, "Input"],

Cell[CellGroupData[{
Cell[8075, 182, 140, 2, 27, "Input"],
Cell[8218, 186, 20025, 627, 186, 6846, 460, "GraphicsData", "PostScript", \
"Graphics"],
Cell[28246, 815, 130, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28413, 823, 35, 1, 27, "Input"],
Cell[28451, 826, 38, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28526, 832, 38, 1, 27, "Input"],
Cell[28567, 835, 59, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28663, 841, 140, 2, 27, "Input"],
Cell[28806, 845, 19098, 558, 186, 5529, 386, "GraphicsData", "PostScript", \
"Graphics"],
Cell[47907, 1405, 130, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48074, 1413, 141, 2, 27, "Input"],
Cell[48218, 1417, 17680, 511, 186, 4928, 349, "GraphicsData", "PostScript", \
"Graphics"],
Cell[65901, 1930, 130, 3, 27, "Output"]
}, Open  ]],
Cell[66046, 1936, 106, 2, 27, "Input"],

Cell[CellGroupData[{
Cell[66177, 1942, 1142, 19, 267, "Input"],
Cell[67322, 1963, 48, 1, 27, "Output"]
}, Open  ]],
Cell[67385, 1967, 26, 0, 27, "Input"],
Cell[67414, 1969, 26, 0, 27, "Input"],
Cell[67443, 1971, 59, 1, 27, "Input"],
Cell[67505, 1974, 730, 15, 203, "Input"],
Cell[68238, 1991, 523, 10, 171, "Input"],
Cell[68764, 2003, 3273, 57, 1057, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

